package com.ruoyi.algorithm.service.impl;

import java.util.List;

import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.ruoyi.algorithm.domain.dto.AlgorithmSceneListDto;
import com.ruoyi.algorithm.utils.FlinkRestApiUtil;
import com.ruoyi.common.config.FlinkConfig;
import com.ruoyi.common.exception.ServiceException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.algorithm.mapper.AlgorithmSceneBaseMapper;
import com.ruoyi.algorithm.domain.AlgorithmSceneBase;
import com.ruoyi.algorithm.service.IAlgorithmSceneBaseService;

/**
 * 算法场景Service业务层处理
 *
 * @author ruoyi
 * @date 2023-04-26
 */
@Service
public class AlgorithmSceneBaseServiceImpl implements IAlgorithmSceneBaseService {
    @Autowired
    private AlgorithmSceneBaseMapper algorithmSceneBaseMapper;

    /**
     * 查询算法场景
     *
     * @param id 算法场景主键
     * @return 算法场景
     */
    @Override
    public AlgorithmSceneBase selectAlgorithmSceneBaseById(Long id) {
        return algorithmSceneBaseMapper.selectAlgorithmSceneBaseById(id);
    }

    /**
     * 查询算法场景列表
     *
     * @param algorithmSceneBase 算法场景
     * @return 算法场景
     */
    @Override
    public List<AlgorithmSceneBase> selectAlgorithmSceneBaseList(AlgorithmSceneBase algorithmSceneBase) {
        return algorithmSceneBaseMapper.selectAlgorithmSceneBaseList(algorithmSceneBase);
    }

    /**
     * 新增算法场景
     *
     * @param algorithmSceneBase 算法场景
     * @return 结果
     */
    @Override
    public int insertAlgorithmSceneBase(AlgorithmSceneBase algorithmSceneBase) {
        return algorithmSceneBaseMapper.insertAlgorithmSceneBase(algorithmSceneBase);
    }

    /**
     * 修改算法场景
     *
     * @param algorithmSceneBase 算法场景
     * @return 结果
     */
    @Override
    public int updateAlgorithmSceneBase(AlgorithmSceneBase algorithmSceneBase) {
        return algorithmSceneBaseMapper.updateAlgorithmSceneBase(algorithmSceneBase);
    }

    /**
     * 批量删除算法场景
     *
     * @param ids 需要删除的算法场景主键
     * @return 结果
     */
    @Override
    public int deleteAlgorithmSceneBaseByIds(Long[] ids) {
        return algorithmSceneBaseMapper.deleteAlgorithmSceneBaseByIds(ids);
    }

    /**
     * 删除算法场景信息
     *
     * @param id 算法场景主键
     * @return 结果
     */
    @Override
    public int deleteAlgorithmSceneBaseById(Long id) {
        return algorithmSceneBaseMapper.deleteAlgorithmSceneBaseById(id);
    }

    @Override
    public List<AlgorithmSceneListDto> selectAlgorithmSceneListDto(AlgorithmSceneBase algorithmSceneBase) {
        return algorithmSceneBaseMapper.selectAlgorithmSceneListDto(algorithmSceneBase);
    }

    @Override
    public int editStatus(AlgorithmSceneBase algorithmSceneBase) {
        //判断状态是否正确
        AlgorithmSceneBase sceneBase = selectAlgorithmSceneBaseById(algorithmSceneBase.getId());
        if (sceneBase.getStatus().equals(algorithmSceneBase.getStatus())) {
            throw new ServiceException("场景状态错误，请刷新后再试！");
        }
        AlgorithmSceneBase newSceneBase = new AlgorithmSceneBase();
        newSceneBase.setId(algorithmSceneBase.getId());
        newSceneBase.setStatus(algorithmSceneBase.getStatus());
        newSceneBase.setJobId("");
        if ("0".equals(algorithmSceneBase.getStatus())) {
            // flink 启动job
            String result = FlinkRestApiUtil.runJar(FlinkConfig.getJarId(), FlinkConfig.getEntryClass()
                    , StrUtil.format(FlinkConfig.getProgramArgs(), algorithmSceneBase.getId()));
            JSONObject jsonObject = JSONUtil.parseObj(result);
            String jobId = jsonObject.getStr("job");
            newSceneBase.setJobId(jobId);
        }else {
            // flink 取消job
            String s = FlinkRestApiUtil.cancelJob(sceneBase.getJobId());
        }
        //修改场景状态
        updateAlgorithmSceneBase(newSceneBase);
        return 1;
    }
}
